# supreme-octo-fiesta
Python package to implement basic matrix operations.
Currently the operations available are scalar and vector multiplication, addition, subtraction, trace and transpose.

Contributors:
Sagnik Mazumder<sagnikmazumdar37@gmail.com>, Sucheta Roy<sucheta56roy@gmail.com>